Do consistent dummy checks for functions (GDTE/GDRF) that use an ADL model
adl.dummy.checks(
x.vrbl,
y.vrbl,
d.x,
d.y,
inferences.x,
inferences.y,
the.coef,
se.type,
type = NULL
)a named vector of the x variables and corresponding lag orders in an ADL model
a named vector of the y variables and corresponding lag orders in an ADL model
the order of differencing of the x variable in the ADL model
the order of differencing of the y variable in the ADL model
is the independent variable treated in levels or in differences?
are the inferences for the dependent variable expected in levels or in differences?
the coefficient vector from the estimated ADL model
the type of standard error calculated
whether the effects are estimated in the context of a GDTE/GDRF
Soren Jordan, Garrett N. Vande Kamp, and Reshi Rajan