Do consistent dummy checks for functions (GDTE/GDRF) that use a GECM model
gecm.dummy.checks(
x.vrbl,
y.vrbl,
x.d.vrbl,
y.d.vrbl,
x.vrbl.d.x,
y.vrbl.d.y,
x.d.vrbl.d.x,
y.d.vrbl.d.y,
inferences.x,
inferences.y,
the.coef,
se.type,
type = NULL
)a named vector of the x variables and corresponding lag orders of lower order of integration (typically levels, 0) in a GECM model
a named vector of the y variables and corresponding lag orders of lower order of integration (typically levels, 0) in a GECM model
a named vector of the x variables and corresponding lag orders of higher order of integration (typically first differences, 1) in a GECM model
a named vector of the y variables and corresponding lag orders of higher order of integration (typically first differences, 1) in a GECM model
the order of differencing of the x variable of lower order of integration (typically levels, 0) in a GECM model
the order of differencing of the y variable of lower order of integration (typically levels, 0) in a GECM model
the order of differencing of the x variable of higher order of integration (typically first differences, 1) in a GECM model
the order of differencing of the y variable of higher order of integration (typically first differences, 1) in a GECM model
is the independent variable treated in levels or in differences?
are the inferences for the dependent variable expected in levels or in differences?
the coefficient vector from the estimated GECM model
the type of standard error calculated
whether the effects are estimated in the context of a GDTE/GDRF
Soren Jordan, Garrett N. Vande Kamp, and Reshi Rajan